==> kafka-4.0.1-src.tgz: kafka-4.0.1-src/metadata/src/main/java/org/apache/kafka/image/node/TopicsImageNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.image.node;

import org.apache.kafka.image.TopicsImage;

import java.util.Arrays;
import java.util.Collection;


public class TopicsImageNode implements MetadataNode {
    /**
     * The name of this node.
     */
    public static final String NAME = "topics";

    /**
     * The topics image.
     */
    private final TopicsImage image;

    public TopicsImageNode(TopicsImage image) {
        this.image = image;
    }

    @Override
    public Collection<String> childNames() {
        return Arrays.asList(TopicsImageByNameNode.NAME, TopicsImageByIdNode.NAME);
    }

    @Override
    public MetadataNode child(String name) {
        if (name.equals(TopicsImageByNameNode.NAME)) {
            return new TopicsImageByNameNode(image);
        } else if (name.equals(TopicsImageByIdNode.NAME)) {
            return new TopicsImageByIdNode(image);
        } else {
            return null;
        }
    }
}

==> kafka-4.1.1-src.tgz: kafka-4.1.1-src/metadata/src/main/java/org/apache/kafka/image/node/TopicsImageNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.image.node;

import org.apache.kafka.image.TopicsImage;

import java.util.Collection;
import java.util.List;


public class TopicsImageNode implements MetadataNode {
    /**
     * The name of this node.
     */
    public static final String NAME = "topics";

    /**
     * The topics image.
     */
    private final TopicsImage image;

    public TopicsImageNode(TopicsImage image) {
        this.image = image;
    }

    @Override
    public Collection<String> childNames() {
        return List.of(TopicsImageByNameNode.NAME, TopicsImageByIdNode.NAME);
    }

    @Override
    public MetadataNode child(String name) {
        if (name.equals(TopicsImageByNameNode.NAME)) {
            return new TopicsImageByNameNode(image);
        } else if (name.equals(TopicsImageByIdNode.NAME)) {
            return new TopicsImageByIdNode(image);
        } else {
            return null;
        }
    }
}
